* OPA660X2 = MDB + MDT + MBC OPERATIONAL TRANSCONDUCTANCE AMPLIFIER
*            AND BUFFER COMPLEX MACROMODEL VERSION
* CREATED  8/92   KL
* REV.A
*
*  ------------------------------------------------------------------------ 
* |  NOTICE: THE INFORMATION PROVIDED HEREIN IS BELIEVED TO BE RELIABLE;   |
* |  HOWEVER; BURR-BROWN ASSUMES NO RESPONSIBILITY FOR INACCURACIES OR     |
* |  OMISSIONS.  BURR-BROWN ASSUMES NO RESPONSIBILITY FOR THE USE OF THIS  |
* |  INFORMATION, AND ALL USE OF SUCH INFORMATION SHALL BE ENTIRELY AT     |
* |  THE USER'S OWN RISK.  NO PATENT RIGHTS OR LICENSES TO ANY OF THE      |
* |  CIRCUITS DESCRIBED HEREIN ARE IMPLIED OR GRANTED TO ANY THIRD PARTY.  |
* |  BURR-BROWN DOES NOT AUTHORIZE OR WARRANT ANY BURR-BROWN PRODUCT FOR   |
* |  USE IN LIFE-SUPPORT DEVICES AND/OR SYSTEMS.                           |
*  ------------------------------------------------------------------------ 
* |-------------------------------------------------------------|
* |  This macro model is being supplied as an aid to            |
* |  circuit designs.  While it reflects reasonably close       |
* |  similarity to the actual device in terms of performance,   |
* |  it is not suggested as a replacement for breadboarding.    |
* |  Simulation should be used as a forerunner or a supplement  |
* |  to traditional lab testing.                                |
* |-------------------------------------------------------------|
*
* CONNECTIONS:   IQ ADJUST
*                | E (EMITTER)
*                | | B (BASE)
*                | | | NEGATIVE SUPPLY
*                | | | | BUFFER IN
*                | | | | | BUFFER OUT
*                | | | | | | POSITIVE SUPPLY
*                | | | | | | | C (COLLECTOR)
*                | | | | | | | |
.SUBCKT OPA660X2 1 2 3 4 5 6 7 8
* 
X1 4 5 6 7 13 14 MDB   ; Diamond Buffer DB
X2 2 3 4 7 8 13 14 MDT ; Diamond Transistor DT
X3 1 4 7 13 14 MBC     ; Biasing Circuit BC
*
C201  1 0  2E-12
C202  2 0  2E-12
C203  3 0  2E-12
C205  5 0  2E-12
C206  6 0  2E-12
C208  8 0  2E-12
*
.ENDS OPA660X2

*Diamond Buffer MDB
*
.SUBCKT MDB 4 5 6 7 13 14
*
R77 77 5 25
*
Q71 74 13  7 7 PI 2.8
Q72 73 14  4 4 NI 2.8
Q73 73 73  7 7 PIJ 18
Q74 74 74  4 4 NIJ 18
Q75 79 73  7 7 PIJ 18
Q76 80 74  4 4 NIJ 18
Q77 74 77 79 7 PIJ
Q78 73 77 80 4 NIJ
Q79 79 79 78 4 NIJ 6
Q80 80 80 78 7 PIJ 6
Q81  7 79  6 4 NIJ 18
Q82  4 80  6 7 PIJ 18
*
.ENDS MDB

*Diamond Transistor MDT
*
.SUBCKT MDT 2 3 4 7 8 13 14
*
R27 27 3 25
R33 33 7 50
R34 34 4 50
R35 35 7 50
R36 36 4 50
*
C38  2 0 2.2E-12
*
Q21 24 13  7 7 PI 2.8
Q22 23 14  4 4 NI 2.8
Q23 23 23  7 7 PIJ 18
Q24 24 24  4 4 NIJ 18
Q25 29 23  7 7 PIJ 18
Q26 30 24  4 4 NIJ 18
Q27 24 27 29 7 PIJ
Q28 23 27 30 4 NIJ
Q29 29 29 28 4 NIJ 6
Q30 30 30 28 7 PIJ 6
Q31 31 29  2 4 NIJ 18
Q32 32 30  2 7 PIJ 18
Q33 31 31 33 7 PIJ 18
Q34 32 32 34 4 NIJ 18
Q35  8 31 35 7 PIJ 18
Q36  8 32 36 4 NIJ 18
*
.ENDS MDT

* Biasing Circuit MBC
*
.SUBCKT MBC 1 4 7 13 14
*
R122 122 4 50E3
R123 122 1 100
*
C121 121 0 10E-12
C124 124 0 10E-12 
*
I121 121 124 0.1E-6
*
E13  13 0  121 0  1
E14  14 0  124 0  1
*
Q121 121 121   7 7 PI
Q122 121 124 122 4 NI 27
Q123 124 121   7 7 PI
Q124 124 124   4 4 NI
Q125   4  13   7 7 PI 32
*
.ENDS MBC

* BIPOLAR TRANSISTOR MODELS
*
.MODEL NI NPN

.MODEL PI PNP

.MODEL NIJ NPN (BF  = 110 IS  = 0.1567E-16
+CJC = 0.029E-12 AF  = 1.000    NE  = 1.366    XTB = 2.452    BR  = 12.89
+CJE = 0.017E-12 EG  = 1.183    NF  = 1.000    XTF = 9.000    IKF = 2.272E-3
+CJS = 0.050E-12 FC  = 0.900    NR  = 1.000    XTI = 2.000    IKR = 16.67E-3
+RB  = 228.0     IRB = 0.000    PTF = 0.000                   ISC = 5.248E-20
+RC  = 48.83     KF  = 0.000    VAR = 1.771                   ISE = 8.040E-18
+RE  = 5.065     MJC = 0.190    VJC = 0.526                   ITF = 6.683E-3
+TF  = 29.80E-12 MJE = 0.493    VJE = 0.816                   RBM = 60.00
+TR  = 65.00E-12 MJS = 0.348    VJS = 0.596                   XCJC= 0.0732
+VAF = 39.00     NC  = 1.634    VTF = 2.680)

.MODEL PIJ PNP (BF  = 110 IS  = 0.1567E-16
+CJC = 0.029E-12 AF  = 1.000    NE  = 1.366    XTB = 2.452    BR  = 12.89
+CJE = 0.017E-12 EG  = 1.183    NF  = 1.000    XTF = 9.000    IKF = 2.272E-3
+CJS = 0.050E-12 FC  = 0.900    NR  = 1.000    XTI = 2.000    IKR = 16.67E-3
+RB  = 228.0     IRB = 0.000    PTF = 0.000                   ISC = 5.248E-20
+RC  = 48.83     KF  = 0.000    VAR = 1.771                   ISE = 8.040E-18
+RE  = 5.065     MJC = 0.190    VJC = 0.526                   ITF = 6.683E-3
+TF  = 29.80E-12 MJE = 0.493    VJE = 0.816                   RBM = 60.00
+TR  = 65.00E-12 MJS = 0.348    VJS = 0.596                   XCJC= 0.0732
+VAF = 39.00     NC  = 1.634    VTF = 2.680)